==> quarkus-vertx-core-1.1.1.Final-sources.jar: io/quarkus/vertx/core/runtime/config/VertxConfiguration$$accessor.java <==
package io.quarkus.vertx.core.runtime.config;
public final class VertxConfiguration$$accessor {
    private VertxConfiguration$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_caching(Object __instance) {
        return ((VertxConfiguration)__instance).caching;
    }
    @SuppressWarnings("unchecked")
    public static void set_caching(Object __instance, boolean caching) {
        ((VertxConfiguration)__instance).caching = caching;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_classpathResolving(Object __instance) {
        return ((VertxConfiguration)__instance).classpathResolving;
    }
    @SuppressWarnings("unchecked")
    public static void set_classpathResolving(Object __instance, boolean classpathResolving) {
        ((VertxConfiguration)__instance).classpathResolving = classpathResolving;
    }
    @SuppressWarnings("unchecked")
    public static Object get_eventLoopsPoolSize(Object __instance) {
        return ((VertxConfiguration)__instance).eventLoopsPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_eventLoopsPoolSize(Object __instance, Object eventLoopsPoolSize) {
        ((VertxConfiguration)__instance).eventLoopsPoolSize = (java.util.OptionalInt)eventLoopsPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxEventLoopExecuteTime(Object __instance) {
        return ((VertxConfiguration)__instance).maxEventLoopExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxEventLoopExecuteTime(Object __instance, Object maxEventLoopExecuteTime) {
        ((VertxConfiguration)__instance).maxEventLoopExecuteTime = (java.util.Optional<java.time.Duration>)maxEventLoopExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_warningExceptionTime(Object __instance) {
        return ((VertxConfiguration)__instance).warningExceptionTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_warningExceptionTime(Object __instance, Object warningExceptionTime) {
        ((VertxConfiguration)__instance).warningExceptionTime = (java.time.Duration)warningExceptionTime;
    }
    @SuppressWarnings("unchecked")
    public static int get_workerPoolSize(Object __instance) {
        return ((VertxConfiguration)__instance).workerPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_workerPoolSize(Object __instance, int workerPoolSize) {
        ((VertxConfiguration)__instance).workerPoolSize = workerPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxWorkerExecuteTime(Object __instance) {
        return ((VertxConfiguration)__instance).maxWorkerExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxWorkerExecuteTime(Object __instance, Object maxWorkerExecuteTime) {
        ((VertxConfiguration)__instance).maxWorkerExecuteTime = (java.util.Optional<java.time.Duration>)maxWorkerExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static int get_internalBlockingPoolSize(Object __instance) {
        return ((VertxConfiguration)__instance).internalBlockingPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_internalBlockingPoolSize(Object __instance, int internalBlockingPoolSize) {
        ((VertxConfiguration)__instance).internalBlockingPoolSize = internalBlockingPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_useAsyncDNS(Object __instance) {
        return ((VertxConfiguration)__instance).useAsyncDNS;
    }
    @SuppressWarnings("unchecked")
    public static void set_useAsyncDNS(Object __instance, boolean useAsyncDNS) {
        ((VertxConfiguration)__instance).useAsyncDNS = useAsyncDNS;
    }
    @SuppressWarnings("unchecked")
    public static Object get_eventbus(Object __instance) {
        return ((VertxConfiguration)__instance).eventbus;
    }
    @SuppressWarnings("unchecked")
    public static void set_eventbus(Object __instance, Object eventbus) {
        ((VertxConfiguration)__instance).eventbus = (EventBusConfiguration)eventbus;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cluster(Object __instance) {
        return ((VertxConfiguration)__instance).cluster;
    }
    @SuppressWarnings("unchecked")
    public static void set_cluster(Object __instance, Object cluster) {
        ((VertxConfiguration)__instance).cluster = (ClusterConfiguration)cluster;
    }
    public static Object construct() {
        return new VertxConfiguration();
    }
}

==> quarkus-vertx-core-1.5.0.Final-sources.jar: io/quarkus/vertx/core/runtime/config/VertxConfiguration$$accessor.java <==
package io.quarkus.vertx.core.runtime.config;
public final class VertxConfiguration$$accessor {
    private VertxConfiguration$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_caching(Object __instance) {
        return ((VertxConfiguration)__instance).caching;
    }
    @SuppressWarnings("unchecked")
    public static void set_caching(Object __instance, boolean caching) {
        ((VertxConfiguration)__instance).caching = caching;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_classpathResolving(Object __instance) {
        return ((VertxConfiguration)__instance).classpathResolving;
    }
    @SuppressWarnings("unchecked")
    public static void set_classpathResolving(Object __instance, boolean classpathResolving) {
        ((VertxConfiguration)__instance).classpathResolving = classpathResolving;
    }
    @SuppressWarnings("unchecked")
    public static Object get_eventLoopsPoolSize(Object __instance) {
        return ((VertxConfiguration)__instance).eventLoopsPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_eventLoopsPoolSize(Object __instance, Object eventLoopsPoolSize) {
        ((VertxConfiguration)__instance).eventLoopsPoolSize = (java.util.OptionalInt)eventLoopsPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxEventLoopExecuteTime(Object __instance) {
        return ((VertxConfiguration)__instance).maxEventLoopExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxEventLoopExecuteTime(Object __instance, Object maxEventLoopExecuteTime) {
        ((VertxConfiguration)__instance).maxEventLoopExecuteTime = (java.util.Optional<java.time.Duration>)maxEventLoopExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_warningExceptionTime(Object __instance) {
        return ((VertxConfiguration)__instance).warningExceptionTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_warningExceptionTime(Object __instance, Object warningExceptionTime) {
        ((VertxConfiguration)__instance).warningExceptionTime = (java.time.Duration)warningExceptionTime;
    }
    @SuppressWarnings("unchecked")
    public static int get_workerPoolSize(Object __instance) {
        return ((VertxConfiguration)__instance).workerPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_workerPoolSize(Object __instance, int workerPoolSize) {
        ((VertxConfiguration)__instance).workerPoolSize = workerPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxWorkerExecuteTime(Object __instance) {
        return ((VertxConfiguration)__instance).maxWorkerExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxWorkerExecuteTime(Object __instance, Object maxWorkerExecuteTime) {
        ((VertxConfiguration)__instance).maxWorkerExecuteTime = (java.util.Optional<java.time.Duration>)maxWorkerExecuteTime;
    }
    @SuppressWarnings("unchecked")
    public static int get_internalBlockingPoolSize(Object __instance) {
        return ((VertxConfiguration)__instance).internalBlockingPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_internalBlockingPoolSize(Object __instance, int internalBlockingPoolSize) {
        ((VertxConfiguration)__instance).internalBlockingPoolSize = internalBlockingPoolSize;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_useAsyncDNS(Object __instance) {
        return ((VertxConfiguration)__instance).useAsyncDNS;
    }
    @SuppressWarnings("unchecked")
    public static void set_useAsyncDNS(Object __instance, boolean useAsyncDNS) {
        ((VertxConfiguration)__instance).useAsyncDNS = useAsyncDNS;
    }
    @SuppressWarnings("unchecked")
    public static Object get_eventbus(Object __instance) {
        return ((VertxConfiguration)__instance).eventbus;
    }
    @SuppressWarnings("unchecked")
    public static void set_eventbus(Object __instance, Object eventbus) {
        ((VertxConfiguration)__instance).eventbus = (EventBusConfiguration)eventbus;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cluster(Object __instance) {
        return ((VertxConfiguration)__instance).cluster;
    }
    @SuppressWarnings("unchecked")
    public static void set_cluster(Object __instance, Object cluster) {
        ((VertxConfiguration)__instance).cluster = (ClusterConfiguration)cluster;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_preferNativeTransport(Object __instance) {
        return ((VertxConfiguration)__instance).preferNativeTransport;
    }
    @SuppressWarnings("unchecked")
    public static void set_preferNativeTransport(Object __instance, boolean preferNativeTransport) {
        ((VertxConfiguration)__instance).preferNativeTransport = preferNativeTransport;
    }
    public static Object construct() {
        return new VertxConfiguration();
    }
}
